==> exo.ecm.wcm.portlet.presentation-1.2-sources.jar: org/exoplatform/wcm/webui/category/UICategoryNavigationConstant.java <==
/*
 * Copyright (C) 2003-2009 eXo Platform SAS.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Affero General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see<http://www.gnu.org/licenses/>.
 */
package org.exoplatform.wcm.webui.category;

/**
 * Created by The eXo Platform SAS
 * Author : eXoPlatform
 *          chuong.phan@exoplatform.com, phan.le.thanh.chuong@gmail.com
 * Jun 29, 2009  
 */
public class UICategoryNavigationConstant {
  
  public static final String PREFERENCE_PORTLET_NAME          = "portletName";
  
  public static final String PREFERENCE_REPOSITORY            = "repository";
  
  public static final String PREFERENCE_TREE_TITLE            = "treeTitle";
  
  public static final String PREFERENCE_TREE_NAME             = "treeName";
  
  public static final String PREFERENCE_TEMPLATE_CATEGORY     = "templateCategory";
  
  public static final String PREFERENCE_TEMPLATE_PATH         = "templatePath";
  
  public static final String PREFERENCE_TARGET_PAGE           = "targetPath";
  
  
  
  public static final String REPOSITORY_FORM_SELECTBOX        = "UICategoryNavigationRepositoryFormSelectBox";
  
  public static final String WORKSPACE_FORM_SELECTBOX         = "UICategoryNavigationWorkspaceFormSelectBox";
  
  public static final String TREE_NAME_FORM_SELECTBOX         = "UICategoryNavigationTreeNameFormSelectBox";
  
  public static final String TEMPLATE_FORM_SELECTBOX          = "UICategoryNavigationTemplateFormSelectBox";
  
  public static final String TREE_TITLE_FORM_STRING_INPUT     = "UICategoryNavigationTreeTitleFormStringInput";
  
  public static final String TARGET_PATH_FORM_INPUT_SET       = "UICategoryNavigationTargetPathFormInputSet";
  
  public static final String TARGET_PATH_FORM_STRING_INPUT    = "UICategoryNavigationTargetPathFormStringInput";
  
  public static final String TARGET_PATH_SELECTOR_POPUP_WINDOW= "UICategoryNavigationTargetPathPopupWindow";
  
}

==> exo.ecm.wcm.portlet.presentation-1.2.1-sources.jar: org/exoplatform/wcm/webui/category/UICategoryNavigationConstant.java <==
/*
 * Copyright (C) 2003-2009 eXo Platform SAS.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Affero General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see<http://www.gnu.org/licenses/>.
 */
package org.exoplatform.wcm.webui.category;

/**
 * Created by The eXo Platform SAS
 * Author : eXoPlatform
 * chuong.phan@exoplatform.com, phan.le.thanh.chuong@gmail.com
 * Jun 29, 2009
 */
public class UICategoryNavigationConstant {
  
  /** The Constant PREFERENCE_PORTLET_NAME. */
  public static final String PREFERENCE_PORTLET_NAME          = "portletName";
  
  /** The Constant PREFERENCE_REPOSITORY. */
  public static final String PREFERENCE_REPOSITORY            = "repository";
  
  /** The Constant PREFERENCE_TREE_TITLE. */
  public static final String PREFERENCE_TREE_TITLE            = "treeTitle";
  
  /** The Constant PREFERENCE_TREE_NAME. */
  public static final String PREFERENCE_TREE_NAME             = "treeName";
  
  /** The Constant PREFERENCE_TEMPLATE_CATEGORY. */
  public static final String PREFERENCE_TEMPLATE_CATEGORY     = "templateCategory";
  
  /** The Constant PREFERENCE_TEMPLATE_PATH. */
  public static final String PREFERENCE_TEMPLATE_PATH         = "templatePath";
  
  /** The Constant PREFERENCE_TARGET_PAGE. */
  public static final String PREFERENCE_TARGET_PAGE           = "targetPath";
  
  /** The Constant REPOSITORY_FORM_SELECTBOX. */
  public static final String REPOSITORY_FORM_SELECTBOX        = "UICategoryNavigationRepositoryFormSelectBox";
  
  /** The Constant WORKSPACE_FORM_SELECTBOX. */
  public static final String WORKSPACE_FORM_SELECTBOX         = "UICategoryNavigationWorkspaceFormSelectBox";
  
  /** The Constant TREE_NAME_FORM_SELECTBOX. */
  public static final String TREE_NAME_FORM_SELECTBOX         = "UICategoryNavigationTreeNameFormSelectBox";
  
  /** The Constant TEMPLATE_FORM_SELECTBOX. */
  public static final String TEMPLATE_FORM_SELECTBOX          = "UICategoryNavigationTemplateFormSelectBox";
  
  /** The Constant TREE_TITLE_FORM_STRING_INPUT. */
  public static final String TREE_TITLE_FORM_STRING_INPUT     = "UICategoryNavigationTreeTitleFormStringInput";
  
  /** The Constant TARGET_PATH_FORM_INPUT_SET. */
  public static final String TARGET_PATH_FORM_INPUT_SET       = "UICategoryNavigationTargetPathFormInputSet";
  
  /** The Constant TARGET_PATH_FORM_STRING_INPUT. */
  public static final String TARGET_PATH_FORM_STRING_INPUT    = "UICategoryNavigationTargetPathFormStringInput";
  
  /** The Constant TARGET_PATH_SELECTOR_POPUP_WINDOW. */
  public static final String TARGET_PATH_SELECTOR_POPUP_WINDOW= "UICategoryNavigationTargetPathPopupWindow";
}
